@@ -1,6 +1,18 @@
 #!/usr/bin/env bash
 
     # Get hold of config parameters, connect to admin system.
+
+    # Attempt to get shared config file from gateway.
+    # It this fails, the user must enter the corresponding data (site and 
+    # admin_url) manually.
+    ADMIN_SITE="http://$(bibos_find_gateway 2> /dev/null)" 
+    SHARED_CONFIG="/tmp/bibos.conf"
+    curl -s "$ADMIN_SITE/bibos.conf" -o "$SHARED_CONFIG"
+
+    if [[ -f "$SHARED_CONFIG" ]]
+    then
+        HAS_GATEWAY=1
+    fi
     # The following config parameters are needed to finalize the
     # installation:
     # - hostname
@@ -20,8 +32,17 @@
     fi
     # - site
     #   TODO: Get site from gateway, if none present prompt user
-    echo "Indtast ID for det site, computeren skal tilmeldes:"
-    read SITE
+    if [[ -n "$HAS_GATEWAY" ]]
+    then
+        SITE=$(get_bibos_config site "$SHARED_CONFIG")
+    fi
+    
+    if [[ -z "$SITE" ]]
+    then 
+        echo "Indtast ID for det site, computeren skal tilmeldes:"
+        read SITE
+    fi
+
     if [[ -n "$SITE" ]]
     then
         sudo set_bibos_config site $SITE
@@ -44,13 +65,20 @@
     fi
     sudo set_bibos_config distribution $DISTRO
     # - admin_url
-    #   TODO: Get from gateway, otherwise prompt user.
-    ADMIN_URL=http://bibos-admin.magenta-aps.dk
-    echo "Indtast admin-url hvis det ikke er $ADMIN_URL"
-    read NEW_ADMIN_URL
-    if [[ -n $NEW_ADMIN_URL ]]
+    #   Get from gateway, otherwise prompt user.
+    if [[ -n "$HAS_GATEWAY" ]]
     then
-        ADMIN_URL=$NEW_ADMIN_URL
+        ADMIN_URL=$(get_bibos_config admin_url "$SHARED_CONFIG")
+    fi
+    if [[ -z "$ADMIN_URL" ]]
+    then 
+        ADMIN_URL=http://bibos-admin.magenta-aps.dk
+        echo "Indtast admin-url hvis det ikke er $ADMIN_URL"
+        read NEW_ADMIN_URL
+        if [[ -n $NEW_ADMIN_URL ]]
+        then
+            ADMIN_URL=$NEW_ADMIN_URL
+        fi
     fi
     sudo set_bibos_config admin_url $ADMIN_URL
 
